from clisy.webview.web_browser_opener import WebBrowserOpener


class DuckDuckGoSearcher:
    duck_duck_go_query_url = "https://duckduckgo.com/?q="

    def open(self, query_string):
        WebBrowserOpener().open(self.duck_duck_go_query_url + query_string)



import logging

from clisy.searcher.searcher_impl.duck_duck_go_searcher import DuckDuckGoSearcher
from clisy.searcher.searchoptions import SearchOptions


class ClisyFactory:
    _logger = logging.getLogger(__name__)
    searchers = {
        SearchOptions.DUCKDUCKGO: DuckDuckGoSearcher
    }

    def __init__(self):
        self.search_option = SearchOptions.DUCKDUCKGO

    def __init__(self, search_option):
        self.search_option = search_option

    def get_searcher(self):
        try:
            return self.searchers[self.search_option]()
        except Exception as ex:
            self._logger.error(self,
                               "This search is not yet supported. Please refer to documentation to understand what "
                               "all options are supported at present. Following are the search options supported so "
                               "far : %s . Here is the error %r",
                               SearchOptions, ex)



class SearchOptions:
    DUCKDUCKGO = "ddg"
    GOOGLE = "g"
    WIKIPEDIA = "w"
    WIRECUTTER = "wc"
    AMAZON = "a"
    CREATIVE_COMMONS = "cc"
    IMDB = "imdb"

    def __str__(self):
        return self.DUCKDUCKGO + "\n" \
               + self.GOOGLE + "\n" \
               + self.WIKIPEDIA + "\n" \
               + self.WIRECUTTER + "\n" \
               + self.AMAZON + "\n" \
               + self.CREATIVE_COMMONS + "\n" \
               + self.IMDB


if __name__ == "__main__":
    print(SearchOptions())



import logging
import subprocess


class WebBrowserOpener:
    _logging = logging.getLogger(__name__)
    SYS_COMMAND_OPEN = "open"

    def open(self, command_string):
        subprocess.call([self.SYS_COMMAND_OPEN, command_string])
